@@ -1,6 +1,9 @@
 from dockit import schema
 from dockit.backends import get_document_backend
 
+from django.db import models
+from django.conf import settings
+
 from copy import deepcopy
 
 import datetime
@@ -71,3 +74,9 @@ class ActiveIndex(schema.Document):
     creation_date = schema.DateTimeField(default=datetime.datetime.now)
     #TODO store the index parameters
 
+class DockitPermission(models.Model):
+    pass #a content type is required for creating permissions
+
+if 'django.contrib.auth' in settings.INSTALLED_APPS:
+    import auth
+
